{ lib
, stdenv
, fetchFromGitHub
, cmake
, ffmpeg_4
, ninja
, pkg-config
, qtbase
, obs-studio
}:

stdenv.mkDerivation rec {
  pname = "obs-streamfx";
  version = "0.12.0b164";

  src = fetchFromGitHub {
    owner = "Xaymar";
    repo = "obs-StreamFx";
    rev = version;
    sha256 = "hxVSoX+qzqvTAhni5mAjZnsAsKeWo3wbXlRQOEoBCBA=";
    fetchSubmodules = true;
  };

  nativeBuildInputs = [ cmake ninja pkg-config ];
  buildInputs = [ ffmpeg_4 obs-studio qtbase ];

  dontWrapQtApps = true;

  cmakeFlags = with lib; [
    "-DCMAKE_BUILD_TYPE=Release"
    "-DENABLE_CLANG=true"
    "-DENABLE_PROFILING=off"
    "-DPACKAGE_NAME=streamfx-nix-${version}"
    "-Dlibobs_DIR=${obs-studio.out}/lib"
    "-DSTRUCTURE_PACKAGEMANAGER=true"
    "-DENABLE_UPDATER=false"
    "-DENABLE_FRONTEND=true"
    "-DREQUIRE_JSON=true"
  ];

  patches = [ ./0001-Add-more-version-prints.patch ];

  meta = with lib; {
    description = "StreamFX is a plugin for OBS® Studio which adds many new effects, filters, sources, transitions and encoders - all for free! Be it 3D Transform, Blur, complex Masking, or even custom shaders, you'll find it all here.";
    homepage = "https://s.xaymar.com/streamfx-dc";
    maintainers = [ ];
    license = licenses.gpl2Plus;
    platforms = [ "x86_64-linux" ];
  };
}
